/**
 * Returns a list of data selector strings in a DSL string.
 * Anything that is not a formatter is classified as a dataselector.
 * @param dslString
 */
export declare const getDataSelectorsFromDSL: (dslString: string) => string[];
interface FormatterInfo {
    type: string;
    paramKey: string;
}
/**
 * Returns all formatters used in a DSL string.
 * Checks for formatter existence based on our FormatterPreset
 * @param dslString
 */
export declare const getFormattersFromDSL: (dslString: string) => FormatterInfo[];
/**
 * Returns info about the last formatter in a DSL string.
 * {
 *    type: <formatter name>
 *    paramKey: <parameter name the formatter call is using>
 * }
 * @param dslString
 */
export declare const getLastFormatterFromDSL: (dslString: string) => FormatterInfo;
/**
 * Helper to build a simple DSL string from data selector, formatter, and formatterParamKey
 * @param dataSelector
 * @param formatter the formatter type (e.g. rangeValue, matchValue, etc)
 * @param formatterParamKey the name of the formatter parameter
 */
export declare const buildDSLFromDataSelectorAndFormatter: (dataSelector: any, formatter: any, formatterParamKey?: string) => string;
/**
 * Helper to return a list of fields names based on a DSL string
 * @param dsl
 * @param dataSources
 * @param vizOptions
 * @param vizContext
 */
export declare const getFieldsFromDSL: (dsl: any, dataSources: any, vizOptions?: {}, vizContext?: {}) => string[];
/**
 * Helper to return a list of field data types based on a DSL string
 * @param dsl
 * @param dataSources
 * @param vizOptions
 * @param vizContext
 */
export declare const getDataTypesFromDSL: (dsl: any, dataSources: any, vizOptions?: {}, vizContext?: {}) => string[];
export {};
